@@ -18,11 +18,12 @@
 */
 
 #include "collectiondb.h"
+
 #include <QtSql>
 
 #include <QDesktopServices>
 #include <qimage.h>
-#include <QCustomEvent>
+#include <QMutex>
 
 class CollectionDbPrivate
 {
@@ -41,7 +42,7 @@ class CollectionDbPrivate
         QString sqlFromStringPL;
         QSqlDatabase *db;
         QSqlQuery *query;
-
+        QMutex mutex;
 
         QString selectionFilter(QString year="", QString genre="", QString artist="", QString album="")
         {
@@ -142,12 +143,18 @@ CollectionDB::escapeString( QString string )
 void CollectionDB::setFilterString( QString string )
 {
     string = escapeString( string );
-    p->sqlQuickFilter = QString( " AND ( lower(artist.name) LIKE lower('%%1%') OR "
+    p->filterString = string;
+    p->sqlQuickFilter = "";
+
+    foreach (QString token, string.split(" ")) {
+            p->sqlQuickFilter += QString( " AND ( lower(artist.name) LIKE lower('%%1%') OR "
                         "lower(album.name) LIKE lower('%%1%') OR "
                         "lower(tags.title) LIKE lower('%%1%') OR "
+                        "lower(genre.name) LIKE lower('%%1%') OR "
+                        "lower(year.name) LIKE lower('%%1%') OR "
                         "lower(tags.url) LIKE lower('%%1%') )")
-                        .arg(string);
-    p->filterString = string;
+                        .arg(token);
+    }
 }
 
 bool CollectionDB::isDbValid()
@@ -255,24 +262,33 @@ void CollectionDB::removePlaylist( QString name )
 
 long CollectionDB::selectSqlNumber( const QString& statement )
 {
+    p->mutex.lock();
+
     if (p->query->exec(statement)) {
         while (p->query->next()) {
+            p->mutex.unlock();
             return p->query->value(0).toInt();
         }
     }
     else
         qDebug() << p->query->lastError();
+    p->mutex.unlock();
     return -1;
 }
 
 
 bool CollectionDB::executeSql( const QString& statement )
 {
-    if (p->query->exec(statement))
+    p->mutex.lock();
+
+    if (p->query->exec(statement)){
+        p->mutex.unlock();
         return true;
+    }
     else {
        qDebug() << p->query->lastError();
        qDebug() << "Statement: " <<  statement;
+       p->mutex.unlock();
        return false;
     }
 }
@@ -280,6 +296,7 @@ bool CollectionDB::executeSql( const QString& statement )
 QList<QStringList> CollectionDB::selectSql( const QString& statement)
 {
     QList<QStringList> tags;
+    p->mutex.lock();
     tags.clear();
     int count;
 
@@ -297,12 +314,14 @@ QList<QStringList> CollectionDB::selectSql( const QString& statement)
        qDebug() << p->db->lastError() << "\n" << p->query->lastError();
        qDebug() << "SQL-query: " << statement;
     }
+
+    p->mutex.unlock();
     return tags;
 }
 
 void CollectionDB::createTables( bool temporary )
 {
-    qDebug() << __FUNCTION__;
+    qDebug() << Q_FUNC_INFO;
 
     //create tag table
     executeSql( QString( "CREATE %1 TABLE tags%2 ("
@@ -369,7 +388,7 @@ void CollectionDB::createTables( bool temporary )
         executeSql( "CREATE INDEX url_tag ON tags( url );" );
 
         // create directory statistics database
-        executeSql( QString( "CREATE TABLE directories ("
+        executeSql( QString( "CREATE TABLE IF NOT EXISTS directories ("
                             "dir VARCHAR(100) UNIQUE,"
                             "changedate INTEGER );" ) );
     }
@@ -378,7 +397,7 @@ void CollectionDB::createTables( bool temporary )
 
 void CollectionDB::dropTables( bool temporary )
 {
-    qDebug() << __FUNCTION__;
+    qDebug() << Q_FUNC_INFO;
 
     executeSql( QString( "DROP TABLE tags%1;" ).arg( temporary ? "_temp" : "" ) );
     executeSql( QString( "DROP TABLE album%1;" ).arg( temporary ? "_temp" : "" ) );
@@ -386,11 +405,6 @@ void CollectionDB::dropTables( bool temporary )
     executeSql( QString( "DROP TABLE genre%1;" ).arg( temporary ? "_temp" : "" ) );
     executeSql( QString( "DROP TABLE year%1;" ).arg( temporary ? "_temp" : "" ) );
 
-    if ( !temporary )
-    {
-        executeSql( QString( "DROP TABLE directories"));
-    }
-
     // force to re-read over all count for random entry
     p->resultCount=0;
 }
@@ -420,7 +434,7 @@ void CollectionDB::moveTempTables()
 
 void CollectionDB::createStatsTable()
 {
-    qDebug() << __FUNCTION__;
+    qDebug() << Q_FUNC_INFO;
 
     // create music statistics database
     executeSql( QString( "CREATE TABLE statistics ("
@@ -448,7 +462,7 @@ void CollectionDB::createStatsTable()
 
 void CollectionDB::dropStatsTable()
 {
-    qDebug() << __FUNCTION__;
+    qDebug() << Q_FUNC_INFO;
 
     executeSql( "DROP TABLE statistics;" );
     executeSql( "DROP TABLE favorites;" );
@@ -514,7 +528,7 @@ QStringList CollectionDB::getRandomEntry(QString path, QString genre, QString ar
             return QStringList();
     }
     else {
-        qDebug() << __FUNCTION__ << " No Track found matching filter";
+        qDebug() << Q_FUNC_INFO << " No Track found matching filter";
         return QStringList();
     }
 }
@@ -532,7 +546,7 @@ QStringList CollectionDB::getRandomEntry()
           p->resultCount=getCount();
      }
 
-    long randomID = (rand() / randMax) * p->resultCount;
+    long randomID = (qrand() / randMax) * p->resultCount;
     //qDebug() << QString::number(randomID);
     QList<QStringList> entries = selectRandomEntry(QString::number(randomID) );
 
