@@ -18,7 +18,11 @@
 #include "player.h"
 
 #include <QtGui>
-#include <QtConcurrentRun>
+#if QT_VERSION >= 0x050000
+ #include <QtConcurrent/QtConcurrent>
+#else
+ #include <QtConcurrentRun>
+#endif
 
 
 void Player::sync_set_state(GstElement* element, GstState state)
@@ -27,7 +31,7 @@ void Player::sync_set_state(GstElement* element, GstState state)
         if(res == GST_STATE_CHANGE_FAILURE) return; \
         if(res == GST_STATE_CHANGE_ASYNC) { \
                 GstState state; \
-                        res = gst_element_get_state(GST_ELEMENT (element), &state, NULL, 1000000000/*GST_CLOCK_TIME_NONE*/); \
+                        res = gst_element_get_state(GST_ELEMENT (element), &state, NULL, GST_CLOCK_TIME_NONE); \
                         if(res == GST_STATE_CHANGE_FAILURE || res == GST_STATE_CHANGE_ASYNC) return; \
 } }
 
@@ -42,21 +46,18 @@ struct Player::Private
 
 void cb_newpad (GstElement *decodebin,
                    GstPad     *pad,
-                   gboolean    last,
                    gpointer    data)
 {
     Player* instance = (Player*)data;
-            instance->newpad(decodebin, pad, last, data);
+            instance->newpad(decodebin, pad, data);
 }
 
 
 void Player::newpad (GstElement *decodebin,
                    GstPad     *pad,
-                   gboolean    last,
                    gpointer    data)
 {
     Q_UNUSED(decodebin);
-    Q_UNUSED(last);
     Q_UNUSED(data);
 
         GstCaps *caps;
@@ -74,7 +75,11 @@ void Player::newpad (GstElement *decodebin,
         }
 
         /* check media type */
+#ifdef GST_API_VERSION_1
+        caps = gst_pad_query_caps (pad,NULL);
+#else
         caps = gst_pad_get_caps (pad);
+#endif
         str = gst_caps_get_structure (caps, 0);
         if (!g_strrstr (gst_structure_get_name (str), "audio")) {
                 gst_caps_unref (caps);
@@ -106,8 +111,7 @@ Player::~Player()
 {
     delete p;
     p=0;
-        cleanup();
-        gst_deinit();
+    cleanup();
 }
 
 GstBusSyncReply Player::bus_cb (GstBus *bus, GstMessage *msg, gpointer data)
@@ -129,15 +133,14 @@ bool Player::prepare()
 {
     //Init Gst
     //
-    QString caps_value = "audio/x-raw-int";
+    QString caps_value = "audio/x-raw";
 
       // On mac we bundle the gstreamer plugins with knowthelist
-    #if defined(Q_OS_DARWIN)
+#if defined(Q_OS_DARWIN)
       QString scanner_path;
       QString plugin_path;
       QString registry_filename;
 
-      caps_value = "audio/x-raw-float";
       QDir pd(QCoreApplication::applicationDirPath() + "/../plugins");
       scanner_path = QCoreApplication::applicationDirPath() + "/../plugins/gst-plugin-scanner";
       plugin_path = QCoreApplication::applicationDirPath() + "/../plugins/gstreamer";
@@ -156,9 +159,18 @@ bool Player::prepare()
       if (!registry_filename.isEmpty()) {
         setenv("GST_REGISTRY", registry_filename.toLocal8Bit().constData(), 1);
       }
-    #endif
+#elif defined(Q_OS_WIN32)
+      QString plugin_path = QCoreApplication::applicationDirPath() + "/plugins";
+      QDir pluginDir(plugin_path);
+      if ( pluginDir.exists())
+        _putenv_s("GST_PLUGIN_PATH", plugin_path.toLocal8Bit());
+
+#endif
+
+      //_putenv_s("GST_DEBUG", "*:4"); //win
+      //setenv("GST_DEBUG", "*:3", 1); //unix
+
 
-      //setenv("GST_DEBUG", "*:3", 1);
       gst_init (0, 0);
 
     //prepare
@@ -169,12 +181,17 @@ bool Player::prepare()
         GstCaps *caps;
         pipeline = gst_pipeline_new ("pipeline");
         bus = gst_pipeline_get_bus (GST_PIPELINE (pipeline));
+
+
+#ifdef GST_API_VERSION_1
+        dec = gst_element_factory_make ("decodebin", "decoder");
+#else
+        dec = gst_element_factory_make ("decodebin2", "decoder");
+        caps_value = "audio/x-raw-int";
+#endif
         caps = gst_caps_new_simple (caps_value.toLatin1().data(),
                                     "channels", G_TYPE_INT, 2, NULL);
-
-
-        dec = gst_element_factory_make ("decodebin2", "decoder");
-        g_signal_connect (dec, "new-decoded-pad", G_CALLBACK (cb_newpad), this);
+        g_signal_connect (dec, "pad-added", G_CALLBACK (cb_newpad), this);
         gst_bin_add (GST_BIN (pipeline), dec);
 
         audio = gst_bin_new ("audiobin");
@@ -212,8 +229,11 @@ bool Player::prepare()
         gst_element_set_state (l_src, GST_STATE_NULL);
         gst_element_link ( l_src,dec);
 
+#ifdef GST_API_VERSION_1
+        gst_bus_set_sync_handler (bus, bus_cb, this, NULL);
+#else
         gst_bus_set_sync_handler (bus, bus_cb, this);
-
+#endif
         gst_object_unref (audiopad);
 
         return pipeline;
@@ -246,7 +266,7 @@ void Player::setEqualizer(QString band, double gain)
 void Player::open(QUrl url)
 {
     //To avoid delays load track in another thread
-    qDebug() << __PRETTY_FUNCTION__ <<":"<<parentWidget()->objectName()<<" url="<<url;
+    qDebug() << Q_FUNC_INFO <<":"<<parentWidget()->objectName()<<" url="<<url;
     QFuture<void> future = QtConcurrent::run( this, &Player::asyncOpen,url);
     p->watcher.setFuture(future);
 }
@@ -254,7 +274,6 @@ void Player::open(QUrl url)
 void Player::asyncOpen(QUrl url)
 {
     p->mutex.lock();
-    QString filename = url.toLocalFile().toUtf8();
     m_length = 0;
     m_position = 0;
     p->isLoaded=false;
@@ -264,8 +283,7 @@ void Player::asyncOpen(QUrl url)
     sync_set_state (GST_ELEMENT (pipeline), GST_STATE_NULL);
 
     GstElement *l_src = gst_bin_get_by_name(GST_BIN(pipeline), "localsrc");
-    g_object_set (G_OBJECT (l_src), "location", filename.toLatin1().data(), NULL);
-    qDebug()<<"player load file:"<<filename.toLatin1().data();
+    g_object_set (G_OBJECT (l_src), "location", (const char*)url.toLocalFile().toUtf8(), NULL);
     sync_set_state (GST_ELEMENT (pipeline), GST_STATE_PAUSED);
     setPosition(QTime(0,0));
 
@@ -276,7 +294,7 @@ void Player::asyncOpen(QUrl url)
 void Player::loadThreadFinished()
 {
     // async load in player done
-    qDebug() << __PRETTY_FUNCTION__ <<":"<<parentWidget()->objectName();
+    qDebug() << Q_FUNC_INFO <<":"<<parentWidget()->objectName();
     p->isLoaded=true;
     emit loadFinished();
 
@@ -288,7 +306,7 @@ void Player::loadThreadFinished()
 void Player::play()
 {
     p->isStarted=true;
-    qDebug() << __PRETTY_FUNCTION__ <<":"<<parentWidget()->objectName();
+    qDebug() << Q_FUNC_INFO <<":"<<parentWidget()->objectName();
     if (p->isLoaded) {
           gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_PLAYING);
     }
@@ -329,10 +347,13 @@ QTime Player::position()
     if (pipeline) {
 
         gint64 value=0;
+
+#ifdef GST_API_VERSION_1
+        if(gst_element_query_position(pipeline, GST_FORMAT_TIME, &value)) {
+#else
         GstFormat fmt = GST_FORMAT_TIME;
-
         if(gst_element_query_position(pipeline, &fmt, &value)) {
-
+#endif
             m_position = static_cast<uint>( ( value / GST_MSECOND ) );
             return QTime(0,0).addMSecs( m_position ); // nanosec -> msec
         }
@@ -344,13 +365,18 @@ QTime Player::position()
 QTime Player::length()
 {
     gint64 value=0;
-    GstFormat fmt = GST_FORMAT_TIME;
 
     if ( m_length == 0 && pipeline){
 
+#ifdef GST_API_VERSION_1
+        if(gst_element_query_duration(pipeline, GST_FORMAT_TIME, &value)) {
+#else
+        GstFormat fmt = GST_FORMAT_TIME;
         if(gst_element_query_duration(pipeline, &fmt, &value)) {
+#endif
             m_length = static_cast<uint>( ( value / GST_MSECOND ));
         }
+        qDebug() << Q_FUNC_INFO <<": Can not get duration";
     }
     return QTime(0,0).addMSecs(  m_length ); // nanosec -> msec
 }
@@ -396,7 +422,7 @@ void Player::messageReceived(GstMessage *message)
 
                 switch (GST_MESSAGE_TYPE (message)) {
                 case GST_STATE_CHANGE_FAILURE: {
-                    qDebug()<< "Gstreamer error:"<< p->error;
+                    qDebug() << Q_FUNC_INFO <<": Gstreamer error:"<< p->error;
                 }
                 case GST_MESSAGE_ERROR: {
                         if ( p->error == "")
@@ -406,10 +432,10 @@ void Player::messageReceived(GstMessage *message)
                             gst_message_parse_error (message, &err, &debug);
                             p->error = "Error #"+QString::number(err->code)+" in module "+QString::number(err->domain)+"\n"+QString::fromUtf8(err->message);
                             if(err->domain != GST_STREAM_ERROR && err->code != GST_STREAM_ERROR_FAILED) {
-                                    p->error += "\nMay be you should install more of gstreamer0.10-plugin-*";
+                                    p->error += "\nMay be you should install more of gstreamer plugins";
                                     lastError = QString::fromUtf8(err->message);
                             }
-                            qDebug()<< "Gstreamer error:"<< p->error;
+                            qDebug() << Q_FUNC_INFO <<": Gstreamer error:"<< p->error;
                             g_error_free (err);
                             g_free (debug);
                             Q_EMIT error();
@@ -417,7 +443,7 @@ void Player::messageReceived(GstMessage *message)
                         break;
                 }
                 case GST_MESSAGE_EOS:{
-                    qDebug() << __PRETTY_FUNCTION__ <<":"<<parentWidget()->objectName()<<" End of track reached";
+                    qDebug() << Q_FUNC_INFO <<":"<<parentWidget()->objectName()<<" End of track reached";
                     Q_EMIT finish();
                     break;
                 }
@@ -443,18 +469,31 @@ void Player::messageReceived(GstMessage *message)
                             gint channels;
                             gdouble peak_dB;
                             gdouble rms;
-                            const GValue *list;
-                            const GValue *value;
                             gint i;
 
-                            list = gst_structure_get_value (s, "peak");
-                            channels = gst_value_list_get_size (list);
+#ifdef GST_API_VERSION_1
+                            const GValue *array_val;
+                            GValueArray *peak_arr;
+
+
+                            array_val = gst_structure_get_value (s, "peak");
+                            peak_arr = (GValueArray *) g_value_get_boxed (array_val);
+                            channels = peak_arr->n_values;
 
                             for (i = 0; i < channels; ++i) {
-                              list = gst_structure_get_value (s, "peak");
-                              value = gst_value_list_get_value (list, i);
-                              peak_dB = g_value_get_double (value);
+                              peak_dB = g_value_get_double (peak_arr->values+i);
+#else
+                             const GValue *list;
+                             const GValue *value;
 
+                             list = gst_structure_get_value (s, "peak");
+                             channels = gst_value_list_get_size (list);
+
+                             for (i = 0; i < channels; ++i) {
+                                 list = gst_structure_get_value (s, "peak");
+                                 value = gst_value_list_get_value (list, i);
+                                 peak_dB = g_value_get_double (value);
+#endif
                               /* converting from dB to normal gives us a value between 0.0 and 1.0 */
                               rms = pow (10, peak_dB / 20);
                               if (i==0)
@@ -467,18 +506,31 @@ void Player::messageReceived(GstMessage *message)
                             gint channels;
                             gdouble peak_dB;
                             gdouble rms;
-                            const GValue *list;
-                            const GValue *value;
-
                             gint i;
 
-                            list = gst_structure_get_value (s, "peak");
-                            channels = gst_value_list_get_size (list);
+#ifdef GST_API_VERSION_1
+                            const GValue *array_val;
+                            GValueArray *peak_arr;
+
+
+                            array_val = gst_structure_get_value (s, "peak");
+                            peak_arr = (GValueArray *) g_value_get_boxed (array_val);
+                            channels = peak_arr->n_values;
 
                             for (i = 0; i < channels; ++i) {
-                              list = gst_structure_get_value (s, "peak");
-                              value = gst_value_list_get_value (list, i);
-                              peak_dB = g_value_get_double (value);
+                              peak_dB = g_value_get_double (peak_arr->values+i);
+#else
+                             const GValue *list;
+                             const GValue *value;
+
+                             list = gst_structure_get_value (s, "peak");
+                             channels = gst_value_list_get_size (list);
+
+                             for (i = 0; i < channels; ++i) {
+                                 list = gst_structure_get_value (s, "peak");
+                                 value = gst_value_list_get_value (list, i);
+                                 peak_dB = g_value_get_double (value);
+#endif
 
                               /* converting from dB to normal gives us a value between 0.0 and 1.0 */
                               rms = pow (10, peak_dB / 20);
@@ -487,7 +539,6 @@ void Player::messageReceived(GstMessage *message)
                               else
                                   rmsout_r=rms;
 
-
                             }
 
                         }
